types

package
v0.3.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 17, 2025 License: MIT Imports: 0 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Compose

func Compose[T, U, V any](fn1 func(T) U, fn2 func(U) V) func(T) V

func Id

func Id[T any](t T) T

The identity map

func Return

func Return[In any, T any](t T) func(In) T

Return the given value, given any input of type In

func Return0

func Return0[T any](t T) func() T

Return the given value, given any input of type In

func Vaule

func Vaule[T any]() (t T)

Types

This section is empty.

Jump to