package
Version:
v0.3.1
Opens a new window with list of versions in this module.
Published: Feb 17, 2025
License: MIT
Opens a new window with license information.
Imports: 0
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
func Compose[T, U, V any](fn1 func(T) U, fn2 func(U) V) func(T) V
func Return[In any, T any](t T) func(In) T
Return the given value, given any input of type In
func Return0[T any](t T) func() T
Return the given value, given any input of type In
func Vaule[T any]() (t T)
Source Files
¶
Click to show internal directories.
Click to hide internal directories.